#!/usr/bin/env node

"""
 * CVE-2021-20323
 * CVE-2021-20323 Bug scanner for WebPentesters and Bugbounty Hunters
 *
 * @Developed By Cappricio Securities <https://cappriciosec.com>
 */


"""
import click 
from .utils.helpers import display_help
from .utils.helpers import banner
from .includes.scan import cvescan
from .includes.filereader import reader
from .utils.configure import new_chatid
from .utils.configure import check_id
from .utils.configure import get_chatid
from .utils.const import Data
from .utils.const import Colors
import webbrowser
import os


def helpbanner(ctx, params, value):
    if value:
        display_help()
        ctx.exit()


@click.command(context_settings=dict(help_option_names=['-h', '--help']))
@click.option('-u', '--url', type=str, help="URL to scan")
@click.option('-i', '--input', type=str, help="lost of input file")
@click.option('-o', '--output', type=str, help="output in text file")
@click.option('-c', '--chatid', type=str, help='Creating Telegram Notification')
@click.option('-b', '--blog', flag_value=True, help='Open Blog to read about Bug')
@click.option('-h', '--help', 'helpbanner', is_flag=True, expose_value=False, is_eager=True, callback=helpbanner, help="help menu")

def main(url, input, output, chatid, blog):
    if url:
       banner()
       cvescan(url,output)

    if input:
       banner()
       reader(input,output)
    
    if chatid:
        banner()
        new_chatid(chatid)
    
    if blog:
        banner()
        open(Data.blog)
    
if __name__ == "__main__":
    yaml_file_path = os.path.expanduser(Data.config_path)
    folder_path = os.path.dirname(yaml_file_path)
    os.makedirs(folder_path, exist_ok=True)
    print(check_id())
    main()
